Node

Struct Node 

pub struct Node {
    pub name: String,
    pub text: String,
    pub children: Vec<Node>,
}
A lightweight XML tree node.

Fields

name: String

Element name.

text: String

Direct text content (trimmed).

children: Vec<Node>

Child nodes in document order.

Implementations

Source

impl Node

pub fn child(&self, name: &str) -> Option<&Node>

Find the first direct child element with the given name.

pub fn children_named<'a>( &'a self, name: &'a str, ) -> impl Iterator<Item = &'a Node> + 'a

Collect children with the given name.

pub fn child_text<'a>(&'a self, name: &str) -> &'a str

Text content of the named child, default empty.

pub fn child_i32(&self, name: &str) -> i32

Parse text of named child as integer.

pub fn child_i64(&self, name: &str) -> i64

Parse text of named child as i64.

pub fn child_bool(&self, name: &str) -> bool

Parse text of named child as boolean (true / false).

pub fn items_named<'a>( &'a self, wrapper: &'a str, item_name: &'a str, ) -> Vec<&'a Node>

Parse a <Wrapper><Quantity/><Items>...</Items></Wrapper> list shape.

pub fn string_items(&self, wrapper: &str, item_name: &str) -> Vec<String>

Parse a <Wrapper><Items>...</Items></Wrapper> list of string contents.

pub fn direct_items<'a>(&'a self, item_name: &'a str) -> Vec<&'a Node>

Parse a <Items>...<Item/>...</Items> list where Items is a direct child.

Use this when you have already descended into the wrapper node and the current node looks like <Wrapper><Quantity/><Items><Item/></Items></Wrapper>.

pub fn direct_string_items(&self, item_name: &str) -> Vec<String>

String variant of direct_items: returns the text of every matching item.